@@ -1,4 +1,4 @@
-/* $Id: cut.c,v 1.27.2.9 2001/06/22 21:47:23 astyanax Exp $ */
+/* $Id: cut.c,v 1.27.2.11 2001/10/03 01:53:09 astyanax Exp $ */
 /**************************************************************************
  *   cut.c                                                                *
  *                                                                        *
@@ -127,6 +127,8 @@ void cut_marked_segment(filestruct * top, int top_x, filestruct * bot,
 	    filebot = next;
 	} else {
 	    filebot = top;
+	    if (top_x > 0)
+		new_magicline();
 	}
     }
     if (top->lineno < edittop->lineno)
@@ -140,6 +142,7 @@ int do_cut_text(void)
 #ifndef NANO_SMALL
     char *tmpstr;
     int newsize, cuttingtoend = 0;
+    int cuttingpartialline = 0;
 #endif
 
 
@@ -198,6 +201,7 @@ int do_cut_text(void)
     }
     if (ISSET(MARK_ISSET)) {
 	if (current->lineno == mark_beginbuf->lineno) {
+	    cuttingpartialline = 1;
 	    tmp = copy_node(current);
 	    newsize = abs(mark_beginx - current_x) + 1;
 
@@ -232,7 +236,7 @@ int do_cut_text(void)
 
 	marked_cut = 1;
 	set_modified();
-	if (cuttingtoend)
+	if (cuttingpartialline || cuttingtoend)
 	    edit_refresh();
 	else
 	    edit_update(current, CENTER);
